mafw.plugins
============

.. automodule:: mafw.plugins

   
   .. rubric:: Functions

   .. autosummary::
   
      register_processors
      register_standard_tables
      register_user_interfaces
   